'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var errors = require('./errors.cjs');

/**
 * A string serializer that uses base64 encoding.
 * @category Serializers
 */
const base64 = {
  description: 'base64',
  fixedSize: null,
  maxSize: null,
  serialize(value) {
    try {
      return new Uint8Array(atob(value).split('').map(c => c.charCodeAt(0)));
    } catch (e) {
      throw new errors.InvalidBaseStringError(value, 64, e);
    }
  },
  deserialize(buffer, offset = 0) {
    const slice = buffer.slice(offset);
    const value = btoa(String.fromCharCode.apply(null, [...slice]));
    return [value, buffer.length];
  }
};

exports.base64 = base64;
//# sourceMappingURL=base64.cjs.map
